Struct ComboBox
pub struct ComboBox<'a, T, Message, Theme = Theme, Renderer = Renderer>{ /* private fields */ }Expand description
A widget for searching and selecting a single value from a list of options.
Example
use iced::widget::combo_box;
struct State {
fruits: combo_box::State<Fruit>,
favorite: Option<Fruit>,
}
#[derive(Debug, Clone)]
enum Fruit {
Apple,
Orange,
Strawberry,
Tomato,
}
#[derive(Debug, Clone)]
enum Message {
FruitSelected(Fruit),
}
fn view(state: &State) -> Element<'_, Message> {
combo_box(
&state.fruits,
"Select your favorite fruit...",
state.favorite.as_ref(),
Message::FruitSelected
)
.into()
}
fn update(state: &mut State, message: Message) {
match message {
Message::FruitSelected(fruit) => {
state.favorite = Some(fruit);
}
}
}
impl std::fmt::Display for Fruit {
fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
f.write_str(match self {
Self::Apple => "Apple",
Self::Orange => "Orange",
Self::Strawberry => "Strawberry",
Self::Tomato => "Tomato",
})
}
}Implementations
impl<'a, T, Message, Theme, Renderer> ComboBox<'a, T, Message, Theme, Renderer>
impl<'a, T, Message, Theme, Renderer> ComboBox<'a, T, Message, Theme, Renderer>
pub fn new(
state: &'a State<T>,
placeholder: &str,
selection: Option<&T>,
on_selected: impl Fn(T) -> Message + 'static,
) -> ComboBox<'a, T, Message, Theme, Renderer>
pub fn new( state: &'a State<T>, placeholder: &str, selection: Option<&T>, on_selected: impl Fn(T) -> Message + 'static, ) -> ComboBox<'a, T, Message, Theme, Renderer>
Creates a new ComboBox with the given list of options, a placeholder,
the current selected value, and the message to produce when an option is
selected.
pub fn on_input(
self,
on_input: impl Fn(String) -> Message + 'static,
) -> ComboBox<'a, T, Message, Theme, Renderer>
pub fn on_input( self, on_input: impl Fn(String) -> Message + 'static, ) -> ComboBox<'a, T, Message, Theme, Renderer>
pub fn on_option_hovered(
self,
on_option_hovered: impl Fn(T) -> Message + 'static,
) -> ComboBox<'a, T, Message, Theme, Renderer>
pub fn on_option_hovered( self, on_option_hovered: impl Fn(T) -> Message + 'static, ) -> ComboBox<'a, T, Message, Theme, Renderer>
Sets the message that will be produced when an option of the
ComboBox is hovered using the arrow keys.
pub fn on_open(
self,
message: Message,
) -> ComboBox<'a, T, Message, Theme, Renderer>
pub fn on_open( self, message: Message, ) -> ComboBox<'a, T, Message, Theme, Renderer>
Sets the message that will be produced when the ComboBox is
opened.
pub fn on_close(
self,
message: Message,
) -> ComboBox<'a, T, Message, Theme, Renderer>
pub fn on_close( self, message: Message, ) -> ComboBox<'a, T, Message, Theme, Renderer>
Sets the message that will be produced when the outside area
of the ComboBox is pressed.
pub fn font(
self,
font: <Renderer as Renderer>::Font,
) -> ComboBox<'a, T, Message, Theme, Renderer>
pub fn font( self, font: <Renderer as Renderer>::Font, ) -> ComboBox<'a, T, Message, Theme, Renderer>
Sets the Renderer::Font of the ComboBox.
pub fn icon(
self,
icon: Icon<<Renderer as Renderer>::Font>,
) -> ComboBox<'a, T, Message, Theme, Renderer>
pub fn icon( self, icon: Icon<<Renderer as Renderer>::Font>, ) -> ComboBox<'a, T, Message, Theme, Renderer>
Sets the text_input::Icon of the ComboBox.
pub fn size(
self,
size: impl Into<Pixels>,
) -> ComboBox<'a, T, Message, Theme, Renderer>
pub fn size( self, size: impl Into<Pixels>, ) -> ComboBox<'a, T, Message, Theme, Renderer>
Sets the text sixe of the ComboBox.
pub fn line_height(
self,
line_height: impl Into<LineHeight>,
) -> ComboBox<'a, T, Message, Theme, Renderer>
pub fn line_height( self, line_height: impl Into<LineHeight>, ) -> ComboBox<'a, T, Message, Theme, Renderer>
Sets the LineHeight of the ComboBox.
pub fn width(
self,
width: impl Into<Length>,
) -> ComboBox<'a, T, Message, Theme, Renderer>
pub fn width( self, width: impl Into<Length>, ) -> ComboBox<'a, T, Message, Theme, Renderer>
Sets the width of the ComboBox.
Sets the height of the menu of the ComboBox.
pub fn text_shaping(
self,
shaping: Shaping,
) -> ComboBox<'a, T, Message, Theme, Renderer>
pub fn text_shaping( self, shaping: Shaping, ) -> ComboBox<'a, T, Message, Theme, Renderer>
Sets the text::Shaping strategy of the ComboBox.
pub fn input_style(
self,
style: impl Fn(&Theme, Status) -> Style + 'a,
) -> ComboBox<'a, T, Message, Theme, Renderer>
pub fn input_style( self, style: impl Fn(&Theme, Status) -> Style + 'a, ) -> ComboBox<'a, T, Message, Theme, Renderer>
Sets the style of the input of the ComboBox.
Sets the style of the menu of the ComboBox.
pub fn input_class(
self,
class: impl Into<<Theme as Catalog>::Class<'a>>,
) -> ComboBox<'a, T, Message, Theme, Renderer>
Available on crate feature advanced only.
pub fn input_class( self, class: impl Into<<Theme as Catalog>::Class<'a>>, ) -> ComboBox<'a, T, Message, Theme, Renderer>
advanced only.Sets the style class of the input of the ComboBox.
Available on crate feature advanced only.
advanced only.Sets the style class of the menu of the ComboBox.